ServerMetadata class
Holds metadata about the connected Valkey/Redis server.
Constructors
- ServerMetadata({required String version, required String serverName, required RunningMode mode, required int maxDatabases})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxDatabases → int
-
The maximum number of databases available for selection.
final
- mode → RunningMode
-
The running mode of the server.
Redis: redis_mode
Valkey: server_mode
Dragonfly: redis_mode
final
- moduleList ↔ List
-
The loaded modules
Redis: bf, timeseries, search, vectorset, ReJSON
Valkey: ldap, bf, search, json
Dragonfly: ReJSON, search
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverName → String
-
The server software name
Redis: redis
Valkey: valkey
Dragonfly: dragonfly
final
- version → String
-
The server version string (e.g., "7.2.4", "9.0.0").
Redis : redis_version:8.4.0
Valkey : redis_version:7.2.4, valkey_version:9.0.0
Dragonfly: redis_version:7.4.0, dragonfly_version:df-v1.36.0
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited