decr method
DECR key
Decrements the number stored at key by one.
If the key does not exist, it is set to 0 before performing the operation.
An error is returned if the key contains a value of the wrong type or
contains a string that can not be represented as integer.
Complexity: O(1)
Returns:
- int: The value of key after the decrement.
Implementation
Future<int> decr(String key) async {
final cmd = <String>['DECR', key];
return executeInt(cmd);
}